wepy.resampling.decisions.clone\_merge module
=============================================

.. automodule:: wepy.resampling.decisions.clone_merge
   :members:
   :undoc-members:
   :show-inheritance:
